==> haskell-tls-session-manager-0.0.0.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-JkWctaF4c4COnxAO7aJTV
key: tls-session-manager-0.0.0.2-JkWctaF4c4COnxAO7aJTV
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
abi: 58637ddbcc4063c4702c695725bbe0a2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-JkWctaF4c4COnxAO7aJTV
depends:
    base-4.10.1.0 auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
    psqueues-0.2.5.0-LxSCxiR9RqQ7rgBtGTPcSm
    tls-1.4.0-8vFYH7JDKKd1Z2yN9fZWLh
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             psqueues-0.2.5.0-LxSCxiR9RqQ7rgBtGTPcSm=7d49d82424344b4f72717fcd8b7c969f
             tls-1.4.0-8vFYH7JDKKd1Z2yN9fZWLh=44a1c94abf42db308e628879d99f7be4
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.2-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-5kJ0oy7N5PJJMgUt7yobPw
key: tls-session-manager-0.0.0.2-5kJ0oy7N5PJJMgUt7yobPw
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
abi: 44e92315f3cb85b49c1661bfdef50f16
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-5kJ0oy7N5PJJMgUt7yobPw
depends:
    base-4.10.1.0 auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
    psqueues-0.2.5.0-LxSCxiR9RqQ7rgBtGTPcSm
    tls-1.4.0-JdOfVafrN1i1ulGP2KKDy3
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             psqueues-0.2.5.0-LxSCxiR9RqQ7rgBtGTPcSm=7d49d82424344b4f72717fcd8b7c969f
             tls-1.4.0-JdOfVafrN1i1ulGP2KKDy3=6ab288cb32e04642266d1be5fc54b08f
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
